@@ -4,10 +4,10 @@
 #' Either number of parameters or sum over parameter lengths.
 #'
 #' @template arg_parset
-#' @param devectorize [\code{logical(1)}]\cr
+#' @param devectorize (`logical(1)`)\cr
 #'   Sum over length of vector parameters?
 #'   Default is code{FALSE}.
-#' @return [\code{integer}].
+#' @return [`integer`].
 #' @examples
 #' ps = makeParamSet(
 #'   makeNumericParam("u"),
@@ -19,8 +19,9 @@
 getParamNr = function(par.set, devectorize = FALSE) {
   assertClass(par.set, "ParamSet")
   assertFlag(devectorize)
-  if (devectorize)
+  if (devectorize) {
     return(sum(getParamLengths(par.set)))
-  else
+  } else {
     return(length(par.set$pars))
+  }
 }
